@@ -27,8 +27,8 @@ has 'content_modified', isa => 'DateTime', is => 'ro';
 has 'credit',       isa => 'Str', is => 'rw';
 has 'priority',     isa => 'Int', is => 'ro', default => 5;
 has 'message_id',   isa => 'Str', is => 'ro';
-has 'slugline',     isa => 'Str', is => 'ro';
-has 'slugline_sep', isa => 'Str', is => 'ro', default => '/';
+has 'slugline',     isa => 'Str', is => 'rw';
+has 'slugline_sep', isa => 'Str', is => 'rw', default => '/';
 has 'electiondistrict', isa => 'XML::NewsML_G2::ElectionDistrict', is => 'rw';
 
 has 'sources',
@@ -38,8 +38,9 @@ has 'sources',
     traits  => ['Array'],
     handles => { add_source => 'push' };
 has 'authors',
-    isa     => 'ArrayRef[Str]',
+    isa     => 'XML::NewsML_G2::ArrayRefOfCreators',
     is      => 'rw',
+    coerce  => 1,
     default => sub { [] },
     traits  => ['Array'],
     handles => { add_author => 'push' };
@@ -153,16 +154,21 @@ sub add_location {
 }
 
 sub add_paragraph {
-    my ( $self, $text ) = @_;
+    my ( $self, $text_or_xml ) = @_;
     my $paras = $self->paragraphs;
     unless ($paras) {
         $self->paragraphs( $paras =
                 XML::LibXML->createDocument()->createElement('paragraphs') );
     }
-    my $doc = $paras->getOwnerDocument;
-    my $p = $doc->createElementNS( 'http://www.w3.org/1999/xhtml', 'p' );
-    $p->appendChild( $doc->createTextNode($text) );
-    $paras->appendChild($p);
+    if ( ref $text_or_xml ) {
+        $paras->appendChild($text_or_xml);
+    }
+    else {
+        my $doc = $paras->getOwnerDocument;
+        my $p = $doc->createElementNS( 'http://www.w3.org/1999/xhtml', 'p' );
+        $p->appendChild( $doc->createTextNode($text_or_xml) );
+        $paras->appendChild($p);
+    }
     return 1;
 }
 
