@@ -8,7 +8,7 @@ my @attrs = (
     qw(desk hltype role ind geo org topic crel crol drol svc
         isbn ean isrol nprov ninat stat sig iso3166_1a2 genre isin medtop
         rnd vidrnd colsp adc group pgrmod copyright_holder electiondistrict
-        electionprovince facet sportfacet sportfacetvalue storytype)
+        electionprovince facet sportfacet sportfacetvalue storytype gyibt)
 );
 
 foreach (@attrs) {
@@ -198,6 +198,34 @@ Scheme for package group mode
 
 Scheme for copyright holder
 
+=item electiondistrict
+
+Scheme for election districts
+
+=item electionprovince
+
+Scheme for election provinces
+
+=item facet
+
+Scheme for facets
+
+=item sportfacet
+
+Scheme for sport facets
+
+=item sportfacetvalue
+
+Scheme for sport facet values
+
+=item storytype
+
+Scheme for storytypes
+
+=item gyibt
+
+Scheme for creator kinds
+
 =back
 
 =head1 METHODS
